@@ -142,6 +142,39 @@ jsBasicGadget <- function(data, nfactor.limit = 20) {
                                          )
                                        )
                               ),
+                              tabPanel("Boxplot",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           boxUI("box")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("box_plot"), type="html", loader="loader6"),
+                                           ggplotdownUI("box")
+                                         )
+                                       )
+                              ),
+                              tabPanel("Barplot",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           barUI("bar")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("bar_plot"), type="html", loader="loader6"),
+                                           ggplotdownUI("bar")
+                                         )
+                                       )
+                              ),
+                              tabPanel("Lineplot",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           lineUI("line")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("line_plot"), type="html", loader="loader6"),
+                                           ggplotdownUI("line")
+                                         )
+                                       )
+                              ),
                               tabPanel("Kaplan-meier plot",
                                        sidebarLayout(
                                          sidebarPanel(
@@ -423,11 +456,11 @@ jsBasicGadget <- function(data, nfactor.limit = 20) {
       tb <- out_tb1()$table
       cap <- out_tb1()$caption
       out.tb1 <- datatable(tb, rownames = T, extensions = "Buttons", caption = cap,
-                          options = c(jstable::opt.tb1("tb1"),
-                                      list(columnDefs = list(list(visible=FALSE, targets= which(colnames(tb) %in% c("test","sig"))))
-                                      ),
-                                      list(scrollX = TRUE)
-                          )
+                           options = c(jstable::opt.tb1("tb1"),
+                                       list(columnDefs = list(list(visible=FALSE, targets= which(colnames(tb) %in% c("test","sig"))))
+                                       ),
+                                       list(scrollX = TRUE)
+                           )
       )
       if ("sig" %in% colnames(tb)){
         out.tb1 = out.tb1 %>% formatStyle("sig", target = 'row' ,backgroundColor = styleEqual("**", 'yellow'))
@@ -490,6 +523,24 @@ jsBasicGadget <- function(data, nfactor.limit = 20) {
       print(out_scatter())
     })
 
+    out_box <- boxServer("box", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
+
+    output$box_plot <- renderPlot({
+      print(out_box())
+    })
+
+    out_bar <- barServer("bar", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
+
+    output$bar_plot <- renderPlot({
+      print(out_bar())
+    })
+
+    out_line <- lineServer("line", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
+
+    output$line_plot <- renderPlot({
+      print(out_line())
+    })
+
     out_kaplan <- callModule(kaplanModule, "kaplan", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
 
     output$kaplan_plot <- renderPlot({
@@ -684,6 +735,39 @@ jsBasicExtAddin <- function(nfactor.limit = 20, max.filesize = 2048){
                                          )
                                        )
                               ),
+                              tabPanel("Boxplot",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           boxUI("box")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("box_plot"), type="html", loader="loader6"),
+                                           ggplotdownUI("box")
+                                         )
+                                       )
+                              ),
+                              tabPanel("Barplot",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           barUI("bar")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("bar_plot"), type="html", loader="loader6"),
+                                           ggplotdownUI("bar")
+                                         )
+                                       )
+                              ),
+                              tabPanel("Lineplot",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           lineUI("line")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("line_plot"), type="html", loader="loader6"),
+                                           ggplotdownUI("line")
+                                         )
+                                       )
+                              ),
                               tabPanel("Kaplan-meier plot",
                                        sidebarLayout(
                                          sidebarPanel(
@@ -844,6 +928,25 @@ jsBasicExtAddin <- function(nfactor.limit = 20, max.filesize = 2048){
       print(out_scatter())
     })
 
+    out_box <- boxServer("box", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
+
+    output$box_plot <- renderPlot({
+      print(out_box())
+    })
+
+    out_bar <- barServer("bar", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
+
+    output$bar_plot <- renderPlot({
+      print(out_bar())
+    })
+
+    out_line <- lineServer("line", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
+
+    output$line_plot <- renderPlot({
+      print(out_line())
+    })
+
+
     out_kaplan <- callModule(kaplanModule, "kaplan", data = data, data_label = data.label, data_varStruct = NULL, nfactor.limit = nfactor.limit)
 
     output$kaplan_plot <- renderPlot({
